@@ -79,6 +79,7 @@ extern void surface_suite_setup(void);
 extern void wkb_in_suite_setup(void);
 extern void wkt_in_suite_setup(void);
 extern void wrapx_suite_setup(void);
+extern void remove_irrelevant_points_for_view_suite_setup(void);
 
 
 /* AND ADD YOUR SUITE SETUP FUNCTION HERE (2 of 2) */
@@ -133,6 +134,7 @@ PG_SuiteSetup setupfuncs[] = {algorithms_suite_setup,
 			      wkt_in_suite_setup,
 			      wkt_out_suite_setup,
 			      wrapx_suite_setup,
+			      remove_irrelevant_points_for_view_suite_setup,
 			      NULL};
 
 
