@@ -594,7 +594,7 @@ static size_t gserialized1_from_lwpoint_size(const LWPOINT *point)
 	size += 4; /* Number of points (one or zero (empty)). */
 	size += sizeof(double) * point->point->npoints * FLAGS_NDIMS(point->flags);
 
-	LWDEBUGF(3, "point size = %d", size);
+	LWDEBUGF(3, "point size = %zu", size);
 
 	return size;
 }
@@ -608,7 +608,7 @@ static size_t gserialized1_from_lwline_size(const LWLINE *line)
 	size += 4; /* Number of points (zero => empty). */
 	size += sizeof(double) * line->points->npoints * FLAGS_NDIMS(line->flags);
 
-	LWDEBUGF(3, "linestring size = %d", size);
+	LWDEBUGF(3, "linestring size = %zu", size);
 
 	return size;
 }
@@ -622,7 +622,7 @@ static size_t gserialized1_from_lwtriangle_size(const LWTRIANGLE *triangle)
 	size += 4; /* Number of points (zero => empty). */
 	size += sizeof(double) * triangle->points->npoints * FLAGS_NDIMS(triangle->flags);
 
-	LWDEBUGF(3, "triangle size = %d", size);
+	LWDEBUGF(3, "triangle size = %zu", size);
 
 	return size;
 }
@@ -644,7 +644,7 @@ static size_t gserialized1_from_lwpoly_size(const LWPOLY *poly)
 		size += sizeof(double) * poly->rings[i]->npoints * FLAGS_NDIMS(poly->flags);
 	}
 
-	LWDEBUGF(3, "polygon size = %d", size);
+	LWDEBUGF(3, "polygon size = %zu", size);
 
 	return size;
 }
@@ -658,7 +658,7 @@ static size_t gserialized1_from_lwcircstring_size(const LWCIRCSTRING *curve)
 	size += 4; /* Number of points (zero => empty). */
 	size += sizeof(double) * curve->points->npoints * FLAGS_NDIMS(curve->flags);
 
-	LWDEBUGF(3, "circstring size = %d", size);
+	LWDEBUGF(3, "circstring size = %zu", size);
 
 	return size;
 }
@@ -676,10 +676,10 @@ static size_t gserialized1_from_lwcollection_size(const LWCOLLECTION *col)
 	{
 		size_t subsize = gserialized1_from_any_size(col->geoms[i]);
 		size += subsize;
-		LWDEBUGF(3, "lwcollection subgeom(%d) size = %d", i, subsize);
+		LWDEBUGF(3, "lwcollection subgeom(%d) size = %zu", i, subsize);
 	}
 
-	LWDEBUGF(3, "lwcollection size = %d", size);
+	LWDEBUGF(3, "lwcollection size = %zu", size);
 
 	return size;
 }
@@ -728,7 +728,7 @@ size_t gserialized1_from_lwgeom_size(const LWGEOM *geom)
 		size += gbox_serialized_size(geom->flags);
 
 	size += gserialized1_from_any_size(geom);
-	LWDEBUGF(3, "%s size = %d", __func__, size);
+	LWDEBUGF(3, "%s size = %zu", __func__, size);
 
 	return size;
 }
@@ -1054,7 +1054,7 @@ static size_t gserialized1_from_gbox(const GBOX *gbox, uint8_t *buf)
 		loc += sizeof(float);
 
 		return_size = (size_t)(loc - buf);
-		LWDEBUGF(4, "returning size %d", return_size);
+		LWDEBUGF(4, "returning size %zu", return_size);
 		return return_size;
 	}
 
@@ -1081,7 +1081,7 @@ static size_t gserialized1_from_gbox(const GBOX *gbox, uint8_t *buf)
 		loc += sizeof(float);
 	}
 	return_size = (size_t)(loc - buf);
-	LWDEBUGF(4, "returning size %d", return_size);
+	LWDEBUGF(4, "returning size %zu", return_size);
 	return return_size;
 }
 
