@@ -15,6 +15,8 @@
 
 #include "../postgis_config.h"
 
+#include <math.h> /* for isnan */
+
 #include "shp2pgsql-core.h"
 #include "../liblwgeom/liblwgeom.h"
 #include "../liblwgeom/lwgeom_log.h" /* for LWDEBUG macros */
@@ -463,7 +465,7 @@ FindPolygons(SHPObject *obj, Ring ***Out)
 		double area = 0.0;
 		Ring *ring;
 
-		/* Set start and end vertexes */
+		/* Set start and end vertices */
 		if (pi == obj->nParts - 1)
 			ve = obj->nVertices;
 		else
@@ -471,7 +473,7 @@ FindPolygons(SHPObject *obj, Ring ***Out)
 
 		vs = obj->panPartStart[pi];
 
-		/* Compute number of vertexes */
+		/* Compute number of vertices */
 		nv = ve - vs;
 
 		/* Allocate memory for a ring */
@@ -481,7 +483,7 @@ FindPolygons(SHPObject *obj, Ring ***Out)
 		ring->next = NULL;
 		ring->linked = 0;
 
-		/* Iterate over ring vertexes */
+		/* Iterate over ring vertices */
 		for (vi = vs; vi < ve; vi++)
 		{
 			int vn = vi+1; /* next vertex for area */
@@ -842,7 +844,6 @@ ShpLoaderOpenShape(SHPLOADERSTATE *state)
 	SHPObject *obj = NULL;
 	int ret = SHPLOADEROK;
 	char name[MAXFIELDNAMELEN];
-	char name2[MAXFIELDNAMELEN];
 	DBFFieldType type = FTInvalid;
 	char *utf8str;
 
@@ -1162,23 +1163,20 @@ ShpLoaderOpenShape(SHPLOADERSTATE *state)
 		 * or after pgsql reserved attribute names
 		 */
 		if (name[0] == '_' ||
-		        ! strcmp(name, "gid") || ! strcmp(name, "tableoid") ||
-		        ! strcmp(name, "cmin") ||
-		        ! strcmp(name, "cmax") ||
-		        ! strcmp(name, "xmin") ||
-		        ! strcmp(name, "xmax") ||
-		        ! strcmp(name, "primary") ||
-		        ! strcmp(name, "oid") || ! strcmp(name, "ctid"))
+		    ! strcmp(name, "gid") ||
+		    ! strcmp(name, "tableoid") ||
+		    ! strcmp(name, "cmin") ||
+		    ! strcmp(name, "cmax") ||
+		    ! strcmp(name, "xmin") ||
+		    ! strcmp(name, "xmax") ||
+		    ! strcmp(name, "primary") ||
+		    ! strcmp(name, "oid") ||
+		    ! strcmp(name, "ctid"))
 		{
-			size_t len = strlen(name);
-			if (len > (MAXFIELDNAMELEN - 2))
-				len = MAXFIELDNAMELEN - 2;
-			strncpy(name2 + 2, name, len);
-			name2[MAXFIELDNAMELEN-1] = '\0';
-			name2[len + 2] = '\0';
-			name2[0] = '_';
-			name2[1] = '_';
-			strcpy(name, name2);
+			char tmp[MAXFIELDNAMELEN] = "__";
+			memcpy(tmp+2, name, MAXFIELDNAMELEN-2);
+			tmp[MAXFIELDNAMELEN-1] = '\0';
+			strncpy(name, tmp, MAXFIELDNAMELEN);
 		}
 
 		/* Avoid duplicating field names */
@@ -1470,7 +1468,7 @@ ShpLoaderGetSQLHeader(SHPLOADERSTATE *state, char **strheader)
 		{
 			stringbuffer_aprintf(sb, "\"%s\".",state->config->schema);
 		}
-		stringbuffer_aprintf(sb, "\"%s\" WHERE false;\n", state->config->table, state->geo_col);
+		stringbuffer_aprintf(sb, "\"%s\" WHERE false;\n", state->config->table);
 		/**out input data is going to be in different srid from target, so need to remove type constraint **/
 		stringbuffer_aprintf(sb, "ALTER TABLE \"pgis_tmp_%s\" ALTER COLUMN \"%s\" TYPE geometry USING ( (\"%s\"::geometry) ); \n", state->config->table,  state->geo_col, state->geo_col);
 	}
@@ -1727,7 +1725,7 @@ ShpLoaderGenerateSQLRowStatement(SHPLOADERSTATE *state, int item, char **strreco
 
 done_cell:
 
-		/* Only put in delimeter if not last field or a shape will follow */
+		/* Only put in delimiter if not last field or a shape will follow */
 		if (state->config->readshape == 1 || i < DBFGetFieldCount(state->hDBFHandle) - 1)
 		{
 			if (state->config->dump_format)
@@ -1833,7 +1831,7 @@ done_cell:
 				}
 			}
 
-			//			free(geometry);
+			lwfree(geometry);
 		}
 
 		/* Tidy up everything */
