@@ -38,7 +38,7 @@ relations. Queries with constant arguments call gserialized_gist_sel,
 queries with relations on both sides call gserialized_gist_joinsel.
 
 gserialized_gist_sel sums up the values in the histogram that overlap
-the contant search box.
+the constant search box.
 
 gserialized_gist_joinsel sums up the product of the overlapping
 cells in each relation's histogram.
@@ -290,7 +290,7 @@ typedef struct {
 /**
 * Given that geodetic boxes are X/Y/Z regardless of the
 * underlying geometry dimensionality and other boxes
-* are guided by HAS_Z/HAS_M in their dimesionality,
+* are guided by HAS_Z/HAS_M in their dimensionality,
 * we have a little utility function to make it easy.
 */
 static int
@@ -1505,7 +1505,11 @@ compute_gserialized_stats_mode(VacAttrStats *stats, AnalyzeAttrFetchFunc fetchfu
 		notnull_cnt++;
 
 		/* Give backend a chance of interrupting us */
+#if POSTGIS_PGSQL_VERSION >= 180
+		vacuum_delay_point(true);
+#else
 		vacuum_delay_point();
+#endif
 	}
 
 	/*
@@ -1723,7 +1727,11 @@ compute_gserialized_stats_mode(VacAttrStats *stats, AnalyzeAttrFetchFunc fetchfu
 		if ( ! nd_box ) continue; /* Skip Null'ed out hard deviants */
 
 		/* Give backend a chance of interrupting us */
+#if POSTGIS_PGSQL_VERSION >= 180
+		vacuum_delay_point(true);
+#else
 		vacuum_delay_point();
+#endif
 
 		/* Find the cells that overlap with this box and put them into the ND_IBOX */
 		nd_box_overlap(nd_stats, nd_box, &nd_ibox);
@@ -1874,7 +1882,7 @@ compute_gserialized_stats(VacAttrStats *stats, AnalyzeAttrFetchFunc fetchfunc,
 *
 * It will need to return a stats builder function reference
 * and a "minimum" sample rows to feed it.
-* If we want analisys to be completely skipped we can return
+* If we want analysis to be completely skipped we can return
 * false and leave output vals untouched.
 *
 * What we know from this call is:
@@ -2263,7 +2271,9 @@ gserialized_sel_internal(PlannerInfo *root, List *args, int varRelid, int mode)
 	nd_stats = pg_nd_stats_from_tuple(vardata.statsTuple, mode);
 	ReleaseVariableStats(vardata);
 	selectivity = estimate_selectivity(&search_box, nd_stats, mode);
-	pfree(nd_stats);
+	if (nd_stats)
+		pfree(nd_stats);
+
 	return selectivity;
 }
 
@@ -2307,7 +2317,7 @@ index_has_attr(Oid index_oid, Oid table_oid, int16 table_attnum)
 		elog(ERROR, "table=%u and index=%u are not related", table_oid, index_oid);
 
 	/* Check if the attnum is in the indkey array */
-	for (int16 i = 0; i < index_form->indkey.dim1; i++)
+	for (int16 i = 0; i < (int16)(index_form->indkey.dim1); i++)
 	{
 		if (index_form->indkey.values[i] == table_attnum)
 		{
@@ -2592,7 +2602,7 @@ Datum gserialized_estimated_extent(PG_FUNCTION_ARGS)
 	char *col = NULL;
 	int16 attnum, idx_attnum;
 	Oid atttypid = InvalidOid;
-	char nsp_tbl[NAMEDATALEN];
+	char nsp_tbl[2*NAMEDATALEN+6];
 	char *tbl;
 	Oid tbl_oid, idx_oid = 0;
 	ND_STATS *nd_stats;
@@ -2617,13 +2627,13 @@ Datum gserialized_estimated_extent(PG_FUNCTION_ARGS)
 		char *nsp = text_to_cstring(PG_GETARG_TEXT_P(0));
 		tbl = text_to_cstring(PG_GETARG_TEXT_P(1));
 		coltxt = PG_GETARG_TEXT_P(2);
-		snprintf(nsp_tbl, NAMEDATALEN, "\"%s\".\"%s\"", nsp, tbl);
+		snprintf(nsp_tbl, sizeof(nsp_tbl), "\"%s\".\"%s\"", nsp, tbl);
 	}
 	if ( PG_NARGS() == 2 )
 	{
 		tbl = text_to_cstring(PG_GETARG_TEXT_P(0));
 		coltxt = PG_GETARG_TEXT_P(1);
-		snprintf(nsp_tbl, NAMEDATALEN, "\"%s\"", tbl);
+		snprintf(nsp_tbl, sizeof(nsp_tbl), "\"%s\"", tbl);
 	}
 
 	/* Parse the namespace/table strings and lookup in system catalogs */
