@@ -53,7 +53,7 @@
  * for SET functions or function normally returning a modified raster, return
  * the original raster
  * for GET functions, return NULL
- * try to deduce a valid parameter value if it makes sence (e.g. out of range
+ * try to deduce a valid parameter value if it makes sense (e.g. out of range
  * index for addBand)
  *
  * Do not put the name of the faulty function for NOTICEs, only with ERRORs.
@@ -167,7 +167,6 @@ void _PG_fini(void);
 
 #define RT_MSG_MAXLEN 256
 
-
 /* ---------------------------------------------------------------- */
 /*  Memory allocation / error reporting hooks                       */
 /* ---------------------------------------------------------------- */
@@ -270,7 +269,7 @@ rt_pg_options(const char* varname)
 static stringlist_t *vsi_option_stringlist = NULL;
 
 
-#if POSTGIS_GDAL_VERSION < 23
+#if POSTGIS_GDAL_VERSION < 20300
 
 /*
 * For older versions of GDAL we  have extracted the list of options
@@ -342,7 +341,7 @@ rt_pg_vsi_load_all_options(void)
 	stringlist_sort(vsi_option_stringlist);
 }
 
-#else /* POSTGIS_GDAL_VERSION < 23 */
+#else /* POSTGIS_GDAL_VERSION < 20300 */
 
 /*
 * For newer versions of GDAL the VSIGetFileSystemOptions() call returns
@@ -414,7 +413,7 @@ rt_pg_vsi_load_all_options(void)
 	stringlist_sort(vsi_option_stringlist);
 }
 
-#endif /* POSTGIS_GDAL_VERSION < 23 */
+#endif /* POSTGIS_GDAL_VERSION < 20300 */
 
 
 static bool
@@ -462,6 +461,7 @@ static char *gdal_datapath = NULL;
 static char *gdal_vsi_options = NULL;
 static char *gdal_enabled_drivers = NULL;
 static bool enable_outdb_rasters = false;
+static bool gdal_cpl_debug = false;
 
 /* ---------------------------------------------------------------- */
 /*  Useful variables                                                */
@@ -784,6 +784,30 @@ _PG_init(void) {
 		);
 	}
 
+	/* Prototype for CPL_Degbuf control function. */
+	if ( postgis_guc_find_option("postgis.gdal_cpl_debug") )
+	{
+		/* In this narrow case the previously installed GUC is tied to the callback in */
+		/* the previously loaded library. Probably this is happening during an */
+		/* upgrade, so the old library is where the callback ties to. */
+		elog(WARNING, "'%s' is already set and cannot be changed until you reconnect", "postgis.gdal_cpl_debug");
+	}
+	else
+	{
+		DefineCustomBoolVariable(
+			"postgis.gdal_cpl_debug", /* name */
+			"Enable GDAL debugging messages", /* short_desc */
+			"GDAL debug messages will be sent at the PgSQL debug log level", /* long_desc */
+			&gdal_cpl_debug, /* valueAddr */
+			false, /* bootValue */
+			PGC_SUSET, /* GucContext context */
+			0, /* int flags */
+			NULL, /* GucBoolCheckHook check_hook */
+			rtpg_gdal_set_cpl_debug, /* GucBoolAssignHook assign_hook */
+			NULL  /* GucShowHook show_hook */
+		);
+	}
+
 	if ( postgis_guc_find_option("postgis.gdal_vsi_options") )
 	{
 		elog(WARNING, "'%s' is already set and cannot be changed until you reconnect", "postgis.gdal_vsi_options");
